# smfscaper
Wrapper Library for scraping simplemachineforums with their main url only.

It contains following functions:
* getBoards() - returns a list of visible boards
* getAllPosts() - returns a list of posts
* getStickyPosts() - returns a list of sticky posts
* getLockedPosts() - returns a list of locked-posts
* getNormalPosts() - returns a list of unlocked and non-sticky posts
* getLatestPosts() - returns the first normal post
